@@ -105,7 +105,7 @@ sub set_from_tag ( $self, $tag ) {
                 # cd to repo root
                 my $chdir_guard = P->file->chdir( $self->{dist}->{root} );
 
-                my $res = $self->{dist}->git->git_run( [ 'commit', '-m', qq[Docker base image changed from "$1:$2" to "$1:$tag"], 'Dockerfile' ] );
+                my $res = $self->{dist}->git->git_run(qq[commit -m"Docker base image changed from \\"$1:$2\\" to \\"$1:$tag\\"" Dockerfile]);
 
                 die "$res" if !$res;
             }
@@ -288,40 +288,50 @@ sub build_local ( $self, $tag, $args ) {
     require Pcore::API::Git;
     require Pcore::API::Docker::Engine;
 
+    my $res;
+
     my $dist = $self->{dist};
 
-    print 'Cloning ... ';
+    if ( !$dist->docker ) {
+        $res = res [ 400, 'Docker is not configured for this dist' ];
+        say $res;
+        return $res;
+    }
 
-    my $clone_root = P->file1->tempdir;
+    my ( $clone_root, $repo );
 
-    # my $res = Pcore::API::Git->git_run_no_root( [ 'clone', $dist->git->upstream->get_clone_url, $clone_root ] );
-    my $res = Pcore::API::Git->git_run_no_root( [ 'clone', $dist->{root}, $clone_root ] );
-    say $res;
-    return $res if !$res;
+    if ( defined $tag ) {
+        print 'Cloning ... ';
 
-    my $repo = Pcore::Dist->new($clone_root);
+        $clone_root = P->file1->tempdir;
 
-    print 'Checking out ... ';
-    $res = $repo->git->git_run("checkout $tag");
-    say $res;
-    return $res if !$res;
+        # my $res = Pcore::API::Git->git_run_no_root( [ 'clone', $dist->git->upstream->get_clone_url, $clone_root ] );
+        $res = Pcore::API::Git->git_run_no_root( [ 'clone', $dist->{root}, $clone_root ] );
+        say $res;
+        return $res if !$res;
 
-    # create duild tags
+        $repo = Pcore::Dist->new($clone_root);
+
+        print 'Checking out ... ';
+        $res = $repo->git->git_run("checkout $tag");
+        say $res;
+        return $res if !$res;
+    }
+    else {
+        $repo = $dist;
+    }
+
+    # create build tags
     my $id      = $repo->id;
-    my $repo_id = $repo->docker->{repo_id};
+    my $repo_id = $dist->docker->{repo_id};
 
     my @tags;
 
-    for ( $id->{branch}, $id->{tags}->@* ) {
-        next if !defined;
+    @tags = map {"$repo_id:$_"} grep {defined} $id->{branch}, $id->{tags}->@* if defined $tag;
 
-        push @tags, "$repo_id:$_";
-    }
+    push @tags, "$repo_id:$id->{hash_short}" if !@tags;
 
-    # add dist-id.yaml
-    P->cfg->write( "$repo->{root}/share/dist-id.yaml", $id );
-
-    my $dockerignore = $self->_build_dockerignore("$clone_root/.dockerignore");
+    my $dockerignore = $self->_build_dockerignore("$repo->{root}/.dockerignore");
 
     print 'Comressing image source ... ';
     my $tar = do {
@@ -329,7 +339,7 @@ sub build_local ( $self, $tag, $args ) {
 
         my $_tar = Archive::Tar->new;
 
-        for my $path ( $clone_root->read_dir( max_depth => 0, is_dir => 0 )->@* ) {
+        for my $path ( $repo->{root}->read_dir( max_depth => 0, is_dir => 0 )->@* ) {
             next if $dockerignore->($path);
 
             my $mode;
@@ -341,9 +351,12 @@ sub build_local ( $self, $tag, $args ) {
                 $mode = P->file->calc_chmod('rw-r--r--');
             }
 
-            $_tar->add_data( "$path", P->file->read_bin("$clone_root/$path"), { mode => $mode } );
+            $_tar->add_data( "$path", P->file->read_bin("$repo->{root}/$path"), { mode => $mode } );
         }
 
+        # add dist-id.yaml
+        $_tar->add_data( 'share/dist-id.yaml', P->data->to_yaml($id), { mode => P->file->calc_chmod('rw-r--r--') } );
+
         $_tar->write;
     };
     say 'done';
@@ -378,12 +391,12 @@ sub build_local ( $self, $tag, $args ) {
         }
     }
 
+    # remove by image id
     if ( $args->{remove} ) {
-        for my $tag (@tags) {
-            print qq[Removing image "$tag" ... ];
-            $res = $docker->image_remove( $tag, 1 );
-            say $res;
-        }
+        print qq[Removing image "$res->{data}" ... ];
+        $res = $docker->image_remove( $res->{data}, 1 );
+        say $res;
+
     }
 
     return res 200;
@@ -398,20 +411,37 @@ sub _build_dockerignore ( $self, $path ) {
 
         for my $line ( P->file->read_lines($path)->@* ) {
 
+            # trim spaces
+            $line =~ s/(?:\A\s+|\s+\z)//smg;
+
+            # remove leading "/"
+            $line =~ s[\A/][]sm;
+
+            # skip empty line
+            next if $line eq $EMPTY;
+
             # skip comments
-            next if $line =~ /\A\s*#/sm;
+            next if $line =~ /\A#/sm;
 
             my $pattern = quotemeta $line;
 
+            # "**" = zero or more number of directories
+            $pattern =~ s[\\[*]\\[*]][.*]smg;
+
+            # "?" = any character, excluding "/"
             $pattern =~ s[\\[?]][[^/]]smg;
 
+            # "*" = any substring, excluding "/"
             $pattern =~ s[\\[*]][[^/]*]smg;
 
+            # if pattern started with "!" - this is "including" pattern
             if ( substr( $line, 0, 2 ) eq '\!' ) {
                 substr $line, 0, 2, $EMPTY;
 
                 push @include, $pattern;
             }
+
+            # otherwise this is "excluding" pattern
             else {
                 push @exclude, $pattern;
             }
